@@ -1,3 +1,4 @@
+from inspector.utils import IS_WINDOWS
 from .recorder import RecorderWindow
 from .base import WindowState
 from .browser import BrowserWindow
@@ -10,3 +11,8 @@ WINDOWS = {
     "manager": ManagerWindow,
     "recorder": RecorderWindow,
 }
+
+if IS_WINDOWS:
+    from .windows import WindowsWindow
+
+    WINDOWS["windows"] = WindowsWindow
